@@ -17,32 +17,34 @@ from collections import OrderedDict
 import functools
 import re
 from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
-import pkg_resources
 
-from google.api_core.client_options import ClientOptions
 from google.api_core import exceptions as core_exceptions
 from google.api_core import gapic_v1
 from google.api_core import retry as retries
+from google.api_core.client_options import ClientOptions
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
+import pkg_resources
 
 try:
     OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
 except AttributeError:  # pragma: NO COVER
     OptionalRetry = Union[retries.Retry, object]  # type: ignore
 
+from google.protobuf import duration_pb2  # type: ignore
+from google.protobuf import field_mask_pb2  # type: ignore
+from google.protobuf import timestamp_pb2  # type: ignore
+from google.rpc import status_pb2  # type: ignore
+
 from google.cloud.scheduler_v1.services.cloud_scheduler import pagers
 from google.cloud.scheduler_v1.types import cloudscheduler
 from google.cloud.scheduler_v1.types import job
 from google.cloud.scheduler_v1.types import job as gcs_job
 from google.cloud.scheduler_v1.types import target
-from google.protobuf import duration_pb2  # type: ignore
-from google.protobuf import field_mask_pb2  # type: ignore
-from google.protobuf import timestamp_pb2  # type: ignore
-from google.rpc import status_pb2  # type: ignore
-from .transports.base import CloudSchedulerTransport, DEFAULT_CLIENT_INFO
-from .transports.grpc_asyncio import CloudSchedulerGrpcAsyncIOTransport
+
 from .client import CloudSchedulerClient
+from .transports.base import DEFAULT_CLIENT_INFO, CloudSchedulerTransport
+from .transports.grpc_asyncio import CloudSchedulerGrpcAsyncIOTransport
 
 
 class CloudSchedulerAsyncClient:
@@ -228,9 +230,9 @@ class CloudSchedulerAsyncClient:
 
             from google.cloud import scheduler_v1
 
-            def sample_list_jobs():
+            async def sample_list_jobs():
                 # Create a client
-                client = scheduler_v1.CloudSchedulerClient()
+                client = scheduler_v1.CloudSchedulerAsyncClient()
 
                 # Initialize request argument(s)
                 request = scheduler_v1.ListJobsRequest(
@@ -241,7 +243,7 @@ class CloudSchedulerAsyncClient:
                 page_result = client.list_jobs(request=request)
 
                 # Handle the response
-                for response in page_result:
+                async for response in page_result:
                     print(response)
 
         Args:
@@ -347,9 +349,9 @@ class CloudSchedulerAsyncClient:
 
             from google.cloud import scheduler_v1
 
-            def sample_get_job():
+            async def sample_get_job():
                 # Create a client
-                client = scheduler_v1.CloudSchedulerClient()
+                client = scheduler_v1.CloudSchedulerAsyncClient()
 
                 # Initialize request argument(s)
                 request = scheduler_v1.GetJobRequest(
@@ -357,7 +359,7 @@ class CloudSchedulerAsyncClient:
                 )
 
                 # Make the request
-                response = client.get_job(request=request)
+                response = await client.get_job(request=request)
 
                 # Handle the response
                 print(response)
@@ -454,9 +456,9 @@ class CloudSchedulerAsyncClient:
 
             from google.cloud import scheduler_v1
 
-            def sample_create_job():
+            async def sample_create_job():
                 # Create a client
-                client = scheduler_v1.CloudSchedulerClient()
+                client = scheduler_v1.CloudSchedulerAsyncClient()
 
                 # Initialize request argument(s)
                 request = scheduler_v1.CreateJobRequest(
@@ -464,7 +466,7 @@ class CloudSchedulerAsyncClient:
                 )
 
                 # Make the request
-                response = client.create_job(request=request)
+                response = await client.create_job(request=request)
 
                 # Handle the response
                 print(response)
@@ -577,16 +579,16 @@ class CloudSchedulerAsyncClient:
 
             from google.cloud import scheduler_v1
 
-            def sample_update_job():
+            async def sample_update_job():
                 # Create a client
-                client = scheduler_v1.CloudSchedulerClient()
+                client = scheduler_v1.CloudSchedulerAsyncClient()
 
                 # Initialize request argument(s)
                 request = scheduler_v1.UpdateJobRequest(
                 )
 
                 # Make the request
-                response = client.update_job(request=request)
+                response = await client.update_job(request=request)
 
                 # Handle the response
                 print(response)
@@ -686,9 +688,9 @@ class CloudSchedulerAsyncClient:
 
             from google.cloud import scheduler_v1
 
-            def sample_delete_job():
+            async def sample_delete_job():
                 # Create a client
-                client = scheduler_v1.CloudSchedulerClient()
+                client = scheduler_v1.CloudSchedulerAsyncClient()
 
                 # Initialize request argument(s)
                 request = scheduler_v1.DeleteJobRequest(
@@ -696,7 +698,7 @@ class CloudSchedulerAsyncClient:
                 )
 
                 # Make the request
-                client.delete_job(request=request)
+                await client.delete_job(request=request)
 
         Args:
             request (Union[google.cloud.scheduler_v1.types.DeleteJobRequest, dict]):
@@ -791,9 +793,9 @@ class CloudSchedulerAsyncClient:
 
             from google.cloud import scheduler_v1
 
-            def sample_pause_job():
+            async def sample_pause_job():
                 # Create a client
-                client = scheduler_v1.CloudSchedulerClient()
+                client = scheduler_v1.CloudSchedulerAsyncClient()
 
                 # Initialize request argument(s)
                 request = scheduler_v1.PauseJobRequest(
@@ -801,7 +803,7 @@ class CloudSchedulerAsyncClient:
                 )
 
                 # Make the request
-                response = client.pause_job(request=request)
+                response = await client.pause_job(request=request)
 
                 # Handle the response
                 print(response)
@@ -897,9 +899,9 @@ class CloudSchedulerAsyncClient:
 
             from google.cloud import scheduler_v1
 
-            def sample_resume_job():
+            async def sample_resume_job():
                 # Create a client
-                client = scheduler_v1.CloudSchedulerClient()
+                client = scheduler_v1.CloudSchedulerAsyncClient()
 
                 # Initialize request argument(s)
                 request = scheduler_v1.ResumeJobRequest(
@@ -907,7 +909,7 @@ class CloudSchedulerAsyncClient:
                 )
 
                 # Make the request
-                response = client.resume_job(request=request)
+                response = await client.resume_job(request=request)
 
                 # Handle the response
                 print(response)
@@ -995,9 +997,9 @@ class CloudSchedulerAsyncClient:
 
             from google.cloud import scheduler_v1
 
-            def sample_run_job():
+            async def sample_run_job():
                 # Create a client
-                client = scheduler_v1.CloudSchedulerClient()
+                client = scheduler_v1.CloudSchedulerAsyncClient()
 
                 # Initialize request argument(s)
                 request = scheduler_v1.RunJobRequest(
@@ -1005,7 +1007,7 @@ class CloudSchedulerAsyncClient:
                 )
 
                 # Make the request
-                response = client.run_job(request=request)
+                response = await client.run_job(request=request)
 
                 # Handle the response
                 print(response)
