@@ -13,22 +13,21 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-import warnings
 from typing import Callable, Dict, Optional, Sequence, Tuple, Union
+import warnings
 
-from google.api_core import grpc_helpers
-from google.api_core import gapic_v1
+from google.api_core import gapic_v1, grpc_helpers
 import google.auth  # type: ignore
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
-
+from google.protobuf import empty_pb2  # type: ignore
 import grpc  # type: ignore
 
 from google.cloud.scheduler_v1beta1.types import cloudscheduler
 from google.cloud.scheduler_v1beta1.types import job
 from google.cloud.scheduler_v1beta1.types import job as gcs_job
-from google.protobuf import empty_pb2  # type: ignore
-from .base import CloudSchedulerTransport, DEFAULT_CLIENT_INFO
+
+from .base import DEFAULT_CLIENT_INFO, CloudSchedulerTransport
 
 
 class CloudSchedulerGrpcTransport(CloudSchedulerTransport):
