@@ -1,6 +1,5 @@
 # -*- coding: utf-8 -*-
-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -14,7 +13,6 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 from .cloudscheduler import (
     CreateJobRequest,
     DeleteJobRequest,
@@ -26,18 +24,15 @@ from .cloudscheduler import (
     RunJobRequest,
     UpdateJobRequest,
 )
-from .job import (
-    Job,
-    RetryConfig,
-)
+from .job import Job, RetryConfig
 from .target import (
     AppEngineHttpTarget,
     AppEngineRouting,
+    HttpMethod,
     HttpTarget,
     OAuthToken,
     OidcToken,
     PubsubTarget,
-    HttpMethod,
 )
 
 __all__ = (
